<?php


/**
 * @file
 * This file describes the definition of hooks provided by the Ogone module
 */

/**
 * This module defines a hook to get data from other modules
 *
 * !!! This code is instructional only, it provides hints on how to implement this hook into your modules !!!
 *
 * When this hook is implemented into a module, the $id is used to fetch the data for the correct item to be paid.
 * e.g. an invoice id or an order id.
 *
 * The ogone module invokes the hook in the ogone_orderoverview function. This function gets it's attributes from the URL.
 * Security wise this is not a problem since nobody will want to pay someone else's bill and if an id is entered that does
 * not exist then the implemented hook should check for that and cancel the call.
 *
 * @param <int> $id
 * The id is a unique identifier or a primary key to get data from a module
 *
 * @return <array or bool>
 * returns an array with payment data if the id was valid, otherwise FALSE
 *
 * @see function ogone_paymentrequestform for more information about the key values
 */
function hook_ogone_data($id) {
  if ($valid) {
    /**
     * This function should return an array of data so the ogone form can be built up.
     * It may contain following data:
     */
    return array(
      //required
      'orderId' => 'The order reference',
      'amount' => 'The amount to be paid as float',
      //optional but advised
      'cn' => 'Name of customer',
      'email' => 'E-mail address of customer',
      'ownerZip' => 'Postal code of customer',
      'ownerAddress' => 'Street and house number of customer',
      'ownerCty' => 'Country of customer',
      'ownerTown' => 'Town or city of customer',
      'ownerTelNo' => 'Phone of customer',
      'com' => 'Order description of purchased items',
      //optional
      'pm' => 'Payment method',
      'brand' => 'Credit card brand',
      'win3DS' => 'MAINW or POPUP',
      'pmList' => 'List of selected payment methods and/or credit card brands. Separated by a ; (semi-colon).',
      'pmListType' => 'The possible values are 0,1 and 2.',
      'comPlus' => 'Field for submitting a value you would like returned in the post sale request.',
      'paramPlus' => 'Field for submitting some parameters and their values you would like returned in the post sale request. module and modHash are reserved keys.',
      'operation' => 'Operation code for the transaction (RES: request for authorization or SAL: request for direct sale)',
      'userId' => 'The username specified in the account\'s user management page',
      //optional override ogone settings
      'currency' => 'the used currency',
      'language' => 'the used language',
      'title' => 'Page title for static template',
      'bgColor' => 'Background color for static template',
      'txtColor' => 'Text color for static template',
      'tblBgColor' => 'Table background color for static template',
      'tblTxtColor' => 'Table text color for static template',
      'buttonBgColor' => 'Button background color for static template',
      'buttonTxtColor' => 'Button text color for static template',
      'logo' => 'Logo filename for static template',
      'fontType' => 'Font type for static template',
      'tp' => 'Path to a template file for dynamic template',
      'homeUrl' => 'URL to redirect to home page',
      'catalogUrl' => 'URL to redirect to catalog page',
      'acceptUrl' => 'URL to redirect after accepted payment',
      'declineUrl' => 'URL to redirect after declined payment',
      'exceptionUrl' => 'URL to redirect after exception on payment',
      'cancelUrl' => 'URL to redirect after canceled payment',
    );
  }
  else {
    /**
     * Or return false if the order is not valid
     */
    return FALSE;
  }
}

/**
 * This module defines a hook to get a themed order overview from any module
 *
 * !!! This code is instructional only, it provides hints on how to implement this hook into your modules !!!
 *
 * @param <string> $prefix
 * The prefix needs to be added to the order id so customers don't get confused when they see
 * a prefix while paying the order, but not in the order overview.
 *
 * @param <string> $id
 * The id is a unique identifier or a primary key to get data from a module
 *
 * @param <string> $form
 * rendered form resulted from drupal_get_form('ogone_paymentrequestform', $optargs)
 *
 * @return <string>
 * returns a themed overview of the order with the form needed to post to Ogone
 */
function hook_ogone_theme_overview($prefix, $id, $form) {
  /**
   * The module implementing this hook is responsible for populating $order
   * with the data needed to create an overview.
   * The module needs to implement a theme for an orderoverview that takes $form as an argument.
   */
  $order = array();
  return theme("ogone_order_overview", $order, $form);
}

/**
 * This module defines a hook to handle accepted payments
 * 
 * !!! This code is instructional only, it provides hints on how to implement this hook into your modules !!!
 *
 * @param <string> $prefix
 * A prefix was added to the order id to prevent double order id's from different modules,
 * Your module will need to know this to remove the prefix and search for the correct order.
 *
 * @param <array> $transaction_feedback
 * the returned http request by Ogone after payment;
 * function ogone_paymentresult() calls this hook when a payment was accepted.
 *
 * @param <string> $status
 * authorized (status 5), stored (status 4), accepted (status 9) or pending (status 41, 51 or 91).
 */
function hook_ogone_payment_accept($prefix, $transaction_feedback, $status) {
  /**
   * Do the processing of the order; Use order_id to look up the correct order
   * and compare the transaction feedback to the data in your database,
   * change your order status, etc...
   */
  $order_id = str_replace($prefix, "", $transaction_feedback['orderId']);
  /**
   * After all checks and updates, return an array with 2 items:
   *  error: if something went wrong, FALSE if no error
   *  redirect: page to be used in drupal_goto(redirect) to prevent refresh
   */
  return array(
    'error' => FALSE,
    'redirect' => 'somepage',
  );
}

/**
 * This module defines a hook to handle declined payments
 *
 * !!! This code is instructional only, it provides hints on how to implement this hook into your modules !!!
 *
 * @param <string> $prefix
 * A prefix was added to the order id to prevent double order id's from different modules,
 * Your module will need to know this to remove the prefix and search for the correct order.
 *
 * @param <array> $transaction_feedback
 * the returned http request by Ogone after payment;
 * function ogone_paymentresult() calls this hook when a payment was accepted.
 *
 * @param <string> $status
 * declined (status 2 or 93)
 */
function hook_ogone_payment_decline($prefix, $transaction_feedback, $status) {
  /**
   * Do the processing of the order; Use order_id to look up the correct order
   * and compare the transaction feedback to the data in your database,
   * change your order status, etc...
   */
  $order_id = str_replace($prefix, "", $transaction_feedback['orderId']);
  /**
   * After all checks and updates, return an array with 2 items:
   *  error: if something went wrong, FALSE if no error
   *  redirect: page to be used in drupal_goto(redirect) to prevent refresh
   */
  return array(
    'error' => FALSE,
    'redirect' => 'somepage',
  );
}

/**
 * This module defines a hook to handle exceptions on payments
 *
 * !!! This code is instructional only, it provides hints on how to implement this hook into your modules !!!
 *
 * @param <string> $prefix
 * A prefix was added to the order id to prevent double order id's from different modules,
 * Your module will need to know this to remove the prefix and search for the correct order.
 *
 * @param <array> $transaction_feedback
 * the returned http request by Ogone after payment;
 * function ogone_paymentresult() calls this hook when a payment was accepted.
 *
 * @param <string> $status
 * uncertain (status 52 or 92)
 */
function hook_ogone_payment_exception($prefix, $transaction_feedback, $status) {
  /**
   * Do the processing of the order; Use order_id to look up the correct order
   * and compare the transaction feedback to the data in your database,
   * change your order status, etc...
   */
  $order_id = str_replace($prefix, "", $transaction_feedback['orderId']);
  /**
   * After all checks and updates, return an array with 2 items:
   *  error: if something went wrong, FALSE if no error
   *  redirect: page to be used in drupal_goto(redirect) to prevent refresh
   */
  return array(
    'error' => FALSE,
    'redirect' => 'somepage',
  );
}

/**
 * This module defines a hook to handle canceled payments
 *
 * !!! This code is instructional only, it provides hints on how to implement this hook into your modules !!!
 *
 * @param <string> $prefix
 * A prefix was added to the order id to prevent double order id's from different modules,
 * Your module will need to know this to remove the prefix and search for the correct order.
 *
 * @param <array> $transaction_feedback
 * the returned http request by Ogone after payment;
 * function ogone_paymentresult() calls this hook when a payment was accepted.
 *
 * @param <string> $status
 * canceled (status 1)
 */
function hook_ogone_payment_cancel($prefix, $transaction_feedback, $status) {
  /**
   * Do the processing of the order; Use order_id to look up the correct order
   * and compare the transaction feedback to the data in your database,
   * change your order status, etc...
   */
  $order_id = str_replace($prefix, "", $transaction_feedback['orderId']);
  /**
   * After all checks and updates, return an array with 2 items:
   *  error: if something went wrong, FALSE if no error
   *  redirect: page to be used in drupal_goto(redirect) to prevent refresh
   */
  return array(
    'error' => FALSE,
    'redirect' => 'somepage',
  );
}